@@ -96,7 +96,7 @@ def apply_features(
         # Don't generate feature is not in features
         if feature_names is not None and key not in feature_names:
             continue
-        data[key] = data.iloc[:, [0]].apply(featfunc)
+        data.loc[:, key] = data.iloc[:, [0]].apply(featfunc)
 
     # Add additional wind features
     data = add_additional_wind_features(data, feature_names)
@@ -104,7 +104,7 @@ def apply_features(
     # Add humidity features
     data = add_humidity_features(data, feature_names)
 
-    # Add solar features
+    # Add solar features; when pj is unavailable a default location is used.
     data = add_additional_solar_features(data, pj, feature_names)
 
     # Return dataframe including all requested features
