@@ -35,8 +35,8 @@ import scipy.optimize
 import structlog
 
 import openstef.monitoring.teams as monitoring
-from openstef.enums import MLModelType
 from openstef.data_classes.prediction_job import PredictionJobDataClass
+from openstef.enums import MLModelType
 from openstef.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstef.tasks.utils.taskcontext import TaskContext
 
@@ -48,7 +48,8 @@ def main(config=None, database=None):
 
     if database is None or config is None:
         raise RuntimeError(
-            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+            "Please specifiy a configmanager and/or database connection object. These"
+            " can be found in the openstef-dbc package."
         )
 
     with TaskContext(taskname, config, database) as context:
@@ -99,10 +100,10 @@ def split_forecast_task(
         # message that something strange is happening
         monitoring.post_teams(
             f"New splitting coefficient(s) for pid **{pj['id']}** deviate strongly "
-            f"from previously stored coefficients.",
+            "from previously stored coefficients.",
             url=context.config.teams.monitoring_url,
-            invalid_coefs=invalid_coefs,
-            coefsdf=coefsdf,
+            invalid_coefficients=invalid_coefs,
+            coefficients_df=coefsdf,
         )
         # Use the last known coefficients for further processing
         return last_coefsdf
